@@ -5,7 +5,7 @@ use Moose;
 
 BEGIN { extends 'Catalyst::Model' }
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 has host           => ( isa => 'Str', is => 'ro', required => 1, default => sub { 'localhost' } );
 has port           => ( isa => 'Int', is => 'ro', required => 1, default => sub { 27017 } );
@@ -221,6 +221,21 @@ if you need this please do:
 
 Creates MongoDB::OID object
 
+=head1 SUPPORT
+
+IRC
+
+  Join #catalyst on irc.perl.org and ask for Getty.
+
+Repository
+
+  http://github.com/Getty/p5-catalyst-model-mongodb
+  Pull request and additional contributors are welcome
+ 
+Issue Tracker
+
+  http://github.com/Getty/p5-catalyst-model-mongodb/issues
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudssus.de>
@@ -228,8 +243,8 @@ Soren Dossing <netcom@sauber.net>
 
 =head1 BUGS 
 
-Please report any bugs or feature requests on the github issue tracker http://github.com/Getty/catalyst-model-mongodb/issues
-or to Getty or sauber on IRC at irc.perl.org, or make a pull request at http://github.com/Getty/catalyst-model-mongodb
+Please report any bugs or feature requests on the github issue tracker http://github.com/Getty/p5-catalyst-model-mongodb/issues
+or to Getty or sauber on IRC at irc.perl.org, or make a pull request at http://github.com/Getty/cp5-catalyst-model-mongodb
 
 =head1 COPYRIGHT & LICENSE 
 
